Cache_ class

Cache entity fields to define ObjectBox queries.

Constructors

Cache_()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

byteList → QueryByteVectorProperty<Cache>
see Cache.byteList
final
id → QueryIntegerProperty<Cache>
see Cache.id
final
key → QueryStringProperty<Cache>
see Cache.key
final